@@ -17,10 +17,10 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 29.14 $
- * @(#) $Id: opcodes.c,v 29.14 2007/02/18 14:24:56 chongo Exp $
+ * @(#) $Revision: 30.2 $
+ * @(#) $Id: opcodes.c,v 30.2 2007/07/10 21:18:08 chongo Exp $
  * @(#) $Source: /usr/local/src/cmd/calc/RCS/opcodes.c,v $
  *
  * Under source code control:	1990/02/15 01:48:19
@@ -1153,7 +1153,7 @@ o_power(void)
 		v1 = v1->v_addr;
 	if (v2->v_type == V_ADDR)
 		v2 = v2->v_addr;
-	powivalue(v1, v2, &tmp);
+	powvalue(v1, v2, &tmp);
 	freevalue(stack--);
 	freevalue(stack);
 	*stack = tmp;
